@@ -23,17 +23,23 @@ class SessionHandler():
   def all_to_database(self, obj_list, overwrite = False):
     session = self.create_session()
     for obj in obj_list:
-      if overwrite == True: obj = self.get_or_create(session, obj)
-      session.add(obj)
+      if overwrite == True:
+        session = self.get_or_create(session, obj)
+      else:
+        session.add(obj)
     return self.commit(session)
   
   def get_or_create(self,session, obj):
+    keys = [key.name for key in inspect(obj.__class__).primary_key]
+    key_values = {k: v for k, v in obj.__dict__.items() if v and k in keys}
     params = {k: v for k, v in obj.__dict__.items() if v and k.startswith("_") == False}
-    instance = session.query(obj.__class__).filter_by(**params).first()
+    instance = session.query(obj.__class__).filter_by(**key_values).first()
     if instance:
-        return instance
+      instance.update(**params)
     else:
-      obj
+      session.add(obj)
+    return session
+      
   
   def get_all(self, classname):
     session = self.create_session()   
